file = Array[ 
"alge_solv.f90",
"algebra.f90",
"assimilation.f90",
"basis.f90",
"derivation.f90",
"ffts.f90",
"file_operate.f90",
"geometry.f90",
"map_function.f90",
"math_const.f90",
"math_function.f90",
"matrix_calc.f90",
"max_min.f90",
"phys_const.f90",
"poly_function.f90",
"special_function.f90",
"statistics.f90",
"stdio.f90",
"thermo_advanced_function.f90",
"thermo_advanced_routine.f90",
"thermo_const.f90",
"thermo_function.f90",
"thermo_routine.f90",
"trajectory.f90",
"typhoon_analy.f90" ]

dir = Array[ 
"Alge_Solv",
"Algebra",
"Assimilation",
"Basis",
"Derivation",
"ffts",
"file_operate",
"Geometry",
"Map_Function",
"Math_Const",
"Math_Function",
"Matrix_Calc",
"max_min",
"Phys_Const",
"Poly_Function",
"Special_Function",
"Statistics",
"stdio",
"Thermo_Advanced_Function",
"Thermo_Advanced_Routine",
"Thermo_Const",
"Thermo_Function",
"Thermo_Routine",
"Trajectory",
"typhoon_analy" ]

for i in 0..file.size-1
  system("rdoc.sh #{file[i]} #{dir[i]}")
end
